package com.genesis.graphview;

import android.graphics.Color;
import android.graphics.DashPathEffect;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.text.format.DateFormat;
import anywheresoftware.b4a.AbsObjectWrapper;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.ActivityObject;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import com.jjoe64.graphview.DefaultLabelFormatter;
import com.jjoe64.graphview.GraphView;
import com.jjoe64.graphview.GridLabelRenderer;
import com.jjoe64.graphview.GridLabelRenderer.GridStyle;
import com.jjoe64.graphview.LegendRenderer;
import com.jjoe64.graphview.LegendRenderer.LegendAlign;
import com.jjoe64.graphview.SecondScale;
import com.jjoe64.graphview.ValueDependentColor;
import com.jjoe64.graphview.Viewport;
import com.jjoe64.graphview.helper.DateAsXAxisLabelFormatter;
import com.jjoe64.graphview.series.BarGraphSeries;
import com.jjoe64.graphview.series.DataPoint;
import com.jjoe64.graphview.series.DataPointInterface;
import com.jjoe64.graphview.series.LineGraphSeries;
import com.jjoe64.graphview.series.OnDataPointTapListener;
import com.jjoe64.graphview.series.PointsGraphSeries;
import com.jjoe64.graphview.series.PointsGraphSeries.Shape;
import com.jjoe64.graphview.series.Series;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;

@BA.ActivityObject
@BA.Version(1.35F)
@BA.ShortName("graph")
public class graphview extends AbsObjectWrapper<GraphView>
{
  private static GraphView graphview1;

  public GraphView Initialize(BA ba, String title)
  {
    graphview1 = new GraphView(ba.context);
    graphview1.setTitle(title);
    graphview1.getLegendRenderer().setVisible(true);

    setObject(graphview1);
    return graphview1;
  }

  public void SetCustomLabel(BA ba, final String sign)
  {
    graphview1.getGridLabelRenderer().setLabelFormatter(new DefaultLabelFormatter()
    {
      public String formatLabel(double value, boolean isValueX) {
        if (isValueX)
        {
          return super.formatLabel(value, isValueX);
        }

        return super.formatLabel(value, isValueX) + sign;
      }
    });
  }

  public void FormatLabels(BA ba, int FractionDigits, int IntegerDigits)
  {
    NumberFormat nf = NumberFormat.getInstance();
    nf.setMinimumFractionDigits(FractionDigits);
    nf.setMinimumIntegerDigits(IntegerDigits);
    graphview1.getGridLabelRenderer().setLabelFormatter(new DefaultLabelFormatter(nf, nf));
  }

  public GraphView AddLineSeries(BA ba, boolean Dates, boolean SecondScale, lineseries[] series)
  {
    if (Dates) {
      graphview1.getGridLabelRenderer().setLabelFormatter(new DateAsXAxisLabelFormatter(ba.activity));
      List list = new ArrayList();
      List listx = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getHighestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getLowestValueX()));
      }

      graphview1.getGridLabelRenderer().setNumHorizontalLabels(3);
      BA.Log("SecondScale: " + SecondScale);
      if (SecondScale) {
        List listminy = new ArrayList();
        List listmaxy = new ArrayList();

        for (int i = 0; i < series.length; i++) {
          listmaxy.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getHighestValueY()));
        }

        for (int i = 0; i < series.length; i++) {
          listminy.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getLowestValueY()));
        }

        for (int i = 0; i < series.length; i++) {
          graphview1.getSecondScale().addSeries((Series)series[i].getObject());
          BA.Log("adding second axis: when dates = true and secondscale = true: " + ((LineGraphSeries)series[i].getObject()).getTitle());
        }

        graphview1.getSecondScale().setMinY(((Double)Collections.min(listminy)).doubleValue());
        graphview1.getSecondScale().setMaxY(((Double)Collections.max(listmaxy)).doubleValue());
        graphview1.getViewport().setScalable(true);
        graphview1.getViewport().setScrollable(true);

        setObject(graphview1);
      }
      else {
        graphview1.getViewport().setMinX(((Double)Collections.min(listx)).doubleValue());
        graphview1.getViewport().setMaxX(((Double)Collections.max(list)).doubleValue());
        graphview1.getViewport().setXAxisBoundsManual(true);
        graphview1.getViewport().setScalable(true);
        graphview1.getViewport().setScrollable(true);

        for (int i = 0; i < series.length; i++) {
          BA.Log("Adding series to Normal Scale when Date = True and SecondScale = False");
          graphview1.addSeries((Series)series[i].getObject());
        }

        setObject(graphview1);
      }

    }
    else if (SecondScale) {
      List listminy = new ArrayList();
      List listmaxy = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        listmaxy.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getHighestValueY()));
        BA.Log("Filling listmaxy: " + ((LineGraphSeries)series[i].getObject()).getHighestValueY());
      }

      for (int i = 0; i < series.length; i++) {
        listminy.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getLowestValueY()));
        BA.Log("Filling listminy: " + ((LineGraphSeries)series[i].getObject()).getLowestValueY());
      }

      setObject(graphview1);
      for (int i = 0; i < series.length; i++)
      {
        graphview1.getSecondScale().addSeries((Series)series[i].getObject());

        BA.Log("adding second axis when Date = False and SecondScale = True: " + ((LineGraphSeries)series[i].getObject()).getTitle());
      }

      graphview1.getSecondScale().setMinY(((Double)Collections.min(listminy)).doubleValue());
      graphview1.getSecondScale().setMaxY(((Double)Collections.max(listmaxy)).doubleValue());
      graphview1.getViewport().setScalable(true);
      graphview1.getViewport().setScrollable(true);
    }
    else
    {
      List list = new ArrayList();
      List listx = new ArrayList();
      List list1 = new ArrayList();
      List listy = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getHighestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getLowestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        list1.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getHighestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        listy.add(Double.valueOf(((LineGraphSeries)series[i].getObject()).getLowestValueY()));
      }

      BA.Log("Setting Viewport Settings");
      graphview1.getViewport().setXAxisBoundsManual(true);
      graphview1.getViewport().setMinX(((Double)Collections.min(listx)).doubleValue());
      graphview1.getViewport().setMaxX(((Double)Collections.max(list)).doubleValue());
      graphview1.getViewport().setYAxisBoundsManual(true);
      graphview1.getViewport().setMinY(((Double)Collections.min(listy)).doubleValue());
      graphview1.getViewport().setMaxY(((Double)Collections.max(list1)).doubleValue());
      graphview1.getViewport().setScalable(true);
      graphview1.getViewport().setScrollable(true);

      for (int i = 0; i < series.length; i++) {
        BA.Log("Adding Series when Date = False and SecondScale = False");
        graphview1.addSeries((Series)series[i].getObject());
        setObject(graphview1);
      }
    }

    BA.Log("Setting Graphview1 = graphview and Return graphview1");

    setObject(graphview1);
    return graphview1;
  }

  public GraphView AddBarSeries(BA ba, boolean Dates, boolean SecondScale, bargraphseries[] series)
  {
    if (Dates) {
      graphview1.getGridLabelRenderer().setLabelFormatter(new DateAsXAxisLabelFormatter(ba.activity));
      List list = new ArrayList();
      List listx = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getHighestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getLowestValueX()));
      }

      graphview1.getGridLabelRenderer().setNumHorizontalLabels(3);

      graphview1.getViewport().setMinX(((Double)Collections.min(listx)).doubleValue());
      graphview1.getViewport().setMaxX(((Double)Collections.max(list)).doubleValue());
      graphview1.getViewport().setXAxisBoundsManual(true);
      graphview1.getViewport().setScalable(true);
      graphview1.getViewport().setScrollable(true);

      setObject(graphview1);
    }
    else
    {
      List list = new ArrayList();
      List listx = new ArrayList();
      List list1 = new ArrayList();
      List listy = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getHighestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getLowestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        list1.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getHighestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        listy.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getLowestValueY()));
      }

      graphview1.getViewport().setXAxisBoundsManual(true);
      graphview1.getViewport().setMinX(((Double)Collections.min(listx)).doubleValue());
      graphview1.getViewport().setMaxX(((Double)Collections.max(list)).doubleValue());
      graphview1.getViewport().setYAxisBoundsManual(true);
      graphview1.getViewport().setMinY(((Double)Collections.min(listy)).doubleValue());
      graphview1.getViewport().setMaxY(((Double)Collections.max(list1)).doubleValue());
      graphview1.getViewport().setScalable(true);
      graphview1.getViewport().setScrollable(true);
    }

    if (SecondScale) {
      List list = new ArrayList();
      List listx = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getHighestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((BarGraphSeries)series[i].getObject()).getLowestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        graphview1.getSecondScale().addSeries((Series)series[i].getObject());
      }
      graphview1.getSecondScale().setMinY(((Double)Collections.min(listx)).doubleValue());
      graphview1.getSecondScale().setMaxY(((Double)Collections.max(list)).doubleValue());
    } else {
      for (int i = 0; i < series.length; i++)
        graphview1.addSeries((Series)series[i].getObject());
    }
    setObject(graphview1);

    return graphview1;
  }

  public GraphView AddPointsSeries(BA ba, boolean Dates, boolean SecondScale, pointgraphseries[] series)
  {
    if (Dates) {
      graphview1.getGridLabelRenderer().setLabelFormatter(new DateAsXAxisLabelFormatter(ba.activity));
      List list = new ArrayList();
      List listx = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getHighestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getLowestValueX()));
      }

      graphview1.getGridLabelRenderer().setNumHorizontalLabels(3);

      graphview1.getViewport().setMinX(((Double)Collections.min(listx)).doubleValue());
      graphview1.getViewport().setMaxX(((Double)Collections.max(list)).doubleValue());
      graphview1.getViewport().setXAxisBoundsManual(true);
      graphview1.getViewport().setScalable(true);
      graphview1.getViewport().setScrollable(true);

      setObject(graphview1);
    }
    else
    {
      List list = new ArrayList();
      List listx = new ArrayList();
      List list1 = new ArrayList();
      List listy = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getHighestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getLowestValueX()));
      }

      for (int i = 0; i < series.length; i++) {
        list1.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getHighestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        listy.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getLowestValueY()));
      }

      graphview1.getViewport().setXAxisBoundsManual(true);
      graphview1.getViewport().setMinX(((Double)Collections.min(listx)).doubleValue());
      graphview1.getViewport().setMaxX(((Double)Collections.max(list)).doubleValue());
      graphview1.getViewport().setYAxisBoundsManual(true);
      graphview1.getViewport().setMinY(((Double)Collections.min(listy)).doubleValue());
      graphview1.getViewport().setMaxY(((Double)Collections.max(list1)).doubleValue());
      graphview1.getViewport().setScalable(true);
      graphview1.getViewport().setScrollable(true);
    }

    if (SecondScale) {
      List list = new ArrayList();
      List listx = new ArrayList();

      for (int i = 0; i < series.length; i++) {
        list.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getHighestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        listx.add(Double.valueOf(((PointsGraphSeries)series[i].getObject()).getLowestValueY()));
      }

      for (int i = 0; i < series.length; i++) {
        graphview1.getSecondScale().addSeries((Series)series[i].getObject());
      }
      graphview1.getSecondScale().setMinY(((Double)Collections.min(listx)).doubleValue());
      graphview1.getSecondScale().setMaxY(((Double)Collections.max(list)).doubleValue());
    } else {
      for (int i = 0; i < series.length; i++) {
        graphview1.addSeries((Series)series[i].getObject());
      }

    }

    setObject(graphview1);
    return graphview1;
  }

  public void SetBackGroundColor(BA ba, int color)
  {
    graphview1.getViewport().setBackgroundColor(color);
  }

  public void SetLegendTextColor(BA ba, int color)
  {
    graphview1.getLegendRenderer().setTextColor(color);
  }

  public void HorizontalLabelColor(BA ba, int color)
  {
    graphview1.getGridLabelRenderer().setHorizontalLabelsColor(color);
  }

  public void VerticalLabelColor(BA ba, int color)
  {
    graphview1.getGridLabelRenderer().setVerticalLabelsColor(color);
  }

  public void SetSecondYScaleColor(BA ba, int color)
  {
    graphview1.getGridLabelRenderer().setVerticalLabelsSecondScaleColor(color);
  }

  public void SetGraphTitleColor(BA ba, int color)
  {
    graphview1.setTitleColor(color);
  }

  public void SetGraphTitleSize(BA ba, int size)
  {
    graphview1.setTitleTextSize(size);
  }

  public void SetGraphViewTextSize(BA ba, float size)
  {
    graphview1.getGridLabelRenderer().setTextSize(size);
  }

  public void SetHorizontalAxisTitle(BA ba, String title, int color)
  {
    graphview1.getGridLabelRenderer().setHorizontalAxisTitle(title);
    graphview1.getGridLabelRenderer().setHorizontalAxisTitleColor(color);
  }

  public void SetVerticalAxisTitle(BA ba, String title, int color)
  {
    graphview1.getGridLabelRenderer().setVerticalAxisTitle(title);
    graphview1.getGridLabelRenderer().setVerticalAxisTitleColor(color);
  }

  public void SetGridStyletoNone(BA ba)
  {
    graphview1.getGridLabelRenderer().setGridStyle(GridLabelRenderer.GridStyle.NONE);
  }

  public void SetGridStyletoHorizontal(BA ba)
  {
    graphview1.getGridLabelRenderer().setGridStyle(GridLabelRenderer.GridStyle.HORIZONTAL);
  }

  public void SetGridStyletoVertical(BA ba)
  {
    graphview1.getGridLabelRenderer().setGridStyle(GridLabelRenderer.GridStyle.VERTICAL);
  }

  public void SetGridStyletoBoth(BA ba)
  {
    graphview1.getGridLabelRenderer().setGridStyle(GridLabelRenderer.GridStyle.BOTH);
  }

  public void SetLegendBackGroundColor(BA ba, int color)
  {
    graphview1.getLegendRenderer().setBackgroundColor(color);
  }

  public void SetLegendMargin(BA ba, int margin)
  {
    graphview1.getLegendRenderer().setMargin(margin);
  }

  public void SetLegendPadding(BA ba, int padding)
  {
    graphview1.getLegendRenderer().setPadding(padding);
  }

  public void SetLegendSpacing(BA ba, int spacing)
  {
    graphview1.getLegendRenderer().setSpacing(spacing);
  }

  public void SetLegendTextSize(BA ba, float textSize)
  {
    graphview1.getLegendRenderer().setTextSize(textSize);
  }

  public void SetLegendWidth(BA ba, int width)
  {
    graphview1.getLegendRenderer().setWidth(width);
  }

  public void SetLegendAlignBottom(BA ba)
  {
    graphview1.getLegendRenderer().setAlign(LegendRenderer.LegendAlign.BOTTOM);
  }

  public void SetLegendAlignTop(BA ba)
  {
    graphview1.getLegendRenderer().setAlign(LegendRenderer.LegendAlign.TOP);
  }

  public void SetLegendAlignMiddle(BA ba)
  {
    graphview1.getLegendRenderer().setAlign(LegendRenderer.LegendAlign.MIDDLE);
  }

  @BA.ActivityObject
  @BA.ShortName("bargraphseries")
  public static class bargraphseries extends AbsObjectWrapper<BarGraphSeries<DataPoint>>
  {
    String EventName1;
    BA b4a1;
    BarGraphSeries<DataPoint> series1 = new BarGraphSeries(new DataPoint[0]);

    public BarGraphSeries<DataPoint> Initialize(BA ba, String eventName, String title, int color, boolean Dates, double[] xdata, double[] ydata) { this.b4a1 = ba;
      this.EventName1 = eventName.toLowerCase(BA.cul);
      if (Dates) {
        DataPoint[] datapoints = new DataPoint[xdata.length];

        Date[] currentDate = new Date[xdata.length];
        for (int i = 0; i < xdata.length; i++) {
          currentDate[i] = new Date(()xdata[i]);

          datapoints[i] = new DataPoint(currentDate[i], ydata[i]);
          this.series1 = new BarGraphSeries(datapoints);
          this.series1.setTitle(title);
          this.series1.setColor(color);
        }
        this.series1.setOnDataPointTapListener(new OnDataPointTapListener()
        {
          public void onTap(Series series, DataPointInterface dataPoint)
          {
            Date clickedDate = new Date(()dataPoint.getX());

            graphview.bargraphseries.this.b4a1.raiseEventFromUI(graphview.bargraphseries.this.b4a1.getSender(), graphview.bargraphseries.this.EventName1 + "_seriesclicked", new Object[] { String.valueOf(dataPoint.getX()), String.valueOf(dataPoint.getY()) });
          }
        });
        setObject(this.series1);
      }
      else {
        DataPoint[] datapoints = new DataPoint[xdata.length];
        for (int i = 0; i < xdata.length; i++) {
          datapoints[i] = new DataPoint(xdata[i], ydata[i]);

          this.series1 = new BarGraphSeries(datapoints);
          this.series1.setTitle(title);
          this.series1.setColor(color);
        }
      }
      this.series1.setOnDataPointTapListener(new OnDataPointTapListener()
      {
        public void onTap(Series series, DataPointInterface dataPoint)
        {
          double y = dataPoint.getY();
          double clickedDate = dataPoint.getX();

          graphview.bargraphseries.this.b4a1.raiseEventFromUI(graphview.bargraphseries.this.b4a1.getSender(), graphview.bargraphseries.this.EventName1 + "_seriesclicked", new Object[] { String.valueOf(dataPoint.getX()), String.valueOf(dataPoint.getY()) });
        }
      });
      setObject(this.series1);

      this.series1.setValueDependentColor(new ValueDependentColor()
      {
        public int get(DataPoint data)
        {
          return Color.rgb((int)data.getX() * 255 / 4, (int)Math.abs(data.getY() * 255.0D / 6.0D), 100);
        }
      });
      this.series1.setSpacing(50);

      return this.series1;
    }

    public void showBarValues(BA ba, BarGraphSeries<DataPoint> series, int color)
    {
      series.setDrawValuesOnTop(true);
      series.setValuesOnTopColor(color);
    }

    public void BarSeriesSpacing(BA ba, BarGraphSeries<DataPoint> series, int spacing)
    {
      series.setSpacing(spacing);
    }
  }

  @BA.ActivityObject
  @BA.ShortName("LineSeries")
  public static class lineseries extends AbsObjectWrapper<LineGraphSeries<DataPoint>>
  {
    String EventName;
    BA b4a;
    LineGraphSeries<DataPoint> series = new LineGraphSeries(new DataPoint[0]);

    public LineGraphSeries<DataPoint> Initialize(BA ba, String eventName, String title, int color, boolean Dates, double[] xdata, double[] ydata) {
      this.b4a = ba;
      this.EventName = eventName;
      this.EventName = eventName.toLowerCase(BA.cul);
      if (Dates) {
        DataPoint[] datapoints = new DataPoint[xdata.length];

        Date[] currentDate = new Date[xdata.length];
        DateFormat.format("yyyy-MM-dd hh:mm", new Date());

        for (int i = 0; i < xdata.length; i++) {
          currentDate[i] = new Date(()xdata[i]);

          datapoints[i] = new DataPoint(currentDate[i], ydata[i]);
          this.series = new LineGraphSeries(datapoints);
          this.series.setTitle(title);
          this.series.setColor(color);
        }
        this.series.setOnDataPointTapListener(new OnDataPointTapListener()
        {
          public void onTap(Series series, DataPointInterface dataPoint)
          {
            Date clickedDate = new Date(()dataPoint.getX());

            graphview.lineseries.this.b4a.raiseEventFromUI(graphview.lineseries.this.b4a.getSender(), graphview.lineseries.this.EventName + "_seriesclicked", new Object[] { String.valueOf(dataPoint.getX()), String.valueOf(dataPoint.getY()) });
          }
        });
        setObject(this.series);
      }
      else {
        DataPoint[] datapoints = new DataPoint[xdata.length];
        BA.Log("xData lenght: " + xdata.length + " " + "yData lenght " + ydata.length);
        for (int i = 0; i < xdata.length; i++) {
          datapoints[i] = new DataPoint(xdata[i], ydata[i]);

          this.series = new LineGraphSeries(datapoints);
          this.series.setTitle(title);
          this.series.setColor(color);
        }
      }
      this.series.setOnDataPointTapListener(new OnDataPointTapListener()
      {
        public void onTap(Series series, DataPointInterface dataPoint)
        {
          double y = dataPoint.getY();
          double clickedDate = dataPoint.getX();

          graphview.lineseries.this.b4a.raiseEventFromUI(graphview.lineseries.this.b4a.getSender(), graphview.lineseries.this.EventName + "_seriesclicked", new Object[] { String.valueOf(dataPoint.getX()), String.valueOf(dataPoint.getY()) });
        }
      });
      setObject(this.series);

      return this.series;
    }

    public void ShowDotDataPoints(BA ba)
    {
      this.series.setDrawDataPoints(true);
      this.series.setDataPointsRadius(10.0F);
      this.series.setThickness(8);
    }

    public void ShowDottedLine(BA ba, int linecolor, int strokewidth)
    {
      Paint paint = new Paint();
      paint.setStyle(Paint.Style.STROKE);
      paint.setColor(linecolor);
      paint.setStrokeWidth(strokewidth);
      paint.setPathEffect(new DashPathEffect(new float[] { 8.0F, 5.0F }, 0.0F));
      this.series.setCustomPaint(paint);
    }

    public void DrawBackGroundColor(BA ba, int color)
    {
      this.series.setDrawBackground(true);
      this.series.setBackgroundColor(color);
    }

    public void DataPointRadius(BA ba, LineGraphSeries<DataPoint> series, int size)
    {
      series.setDataPointsRadius(size);
    }

    public void AppendData(BA ba, double x, double y, int viewportsize)
    {
      this.series.appendData(new DataPoint(x, y), true, viewportsize);
    }

    public DataPoint[] ResetData(BA ba, double[] x, double[] y)
    {
      DataPoint[] values = new DataPoint[x.length];
      for (int i = 0; i < values.length; i++) {
        DataPoint v = new DataPoint(x[i], y[i]);
        values[i] = v;
      }
      return values;
    }
  }

  @BA.ActivityObject
  @BA.ShortName("PointGraphSeries")
  public static class pointgraphseries extends AbsObjectWrapper<PointsGraphSeries<DataPoint>>
  {
    String EventName;
    BA b4a;
    PointsGraphSeries<DataPoint> series = new PointsGraphSeries(new DataPoint[0]);

    public PointsGraphSeries<DataPoint> Initialize(BA ba, String eventName, String title, int color, boolean Dates, double[] xdata, double[] ydata) {
      this.b4a = ba;
      this.EventName = eventName;
      this.EventName = eventName.toLowerCase(BA.cul);
      if (Dates) {
        DataPoint[] datapoints = new DataPoint[xdata.length];

        Date[] currentDate = new Date[xdata.length];
        DateFormat.format("yyyy-MM-dd hh:mm", new Date());

        for (int i = 0; i < xdata.length; i++) {
          currentDate[i] = new Date(()xdata[i]);

          datapoints[i] = new DataPoint(currentDate[i], ydata[i]);
          this.series = new PointsGraphSeries(datapoints);
          this.series.setTitle(title);
          this.series.setColor(color);
        }
        this.series.setOnDataPointTapListener(new OnDataPointTapListener()
        {
          public void onTap(Series series, DataPointInterface dataPoint)
          {
            Date clickedDate = new Date(()dataPoint.getX());

            graphview.pointgraphseries.this.b4a.raiseEventFromUI(graphview.pointgraphseries.this.b4a.getSender(), graphview.pointgraphseries.this.EventName + "_seriesclicked", new Object[] { String.valueOf(dataPoint.getX()), String.valueOf(dataPoint.getY()) });
          }
        });
        setObject(this.series);
      }
      else {
        DataPoint[] datapoints = new DataPoint[xdata.length];
        for (int i = 0; i < xdata.length; i++) {
          datapoints[i] = new DataPoint(xdata[i], ydata[i]);

          this.series = new PointsGraphSeries(datapoints);
          this.series.setTitle(title);
          this.series.setColor(color);
        }
      }
      this.series.setOnDataPointTapListener(new OnDataPointTapListener()
      {
        public void onTap(Series series, DataPointInterface dataPoint)
        {
          double y = dataPoint.getY();
          double clickedDate = dataPoint.getX();

          graphview.pointgraphseries.this.b4a.raiseEventFromUI(graphview.pointgraphseries.this.b4a.getSender(), graphview.pointgraphseries.this.EventName + "_seriesclicked", new Object[] { String.valueOf(dataPoint.getX()), String.valueOf(dataPoint.getY()) });
        }
      });
      setObject(this.series);

      return this.series;
    }

    public void SetPointShape(BA ba)
    {
      this.series.setShape(PointsGraphSeries.Shape.POINT);
    }

    public void SetRectangleShape(BA ba)
    {
      this.series.setShape(PointsGraphSeries.Shape.RECTANGLE);
    }

    public void SetTriangleShape(BA ba)
    {
      this.series.setShape(PointsGraphSeries.Shape.TRIANGLE);
    }
  }
}